@@ -15,6 +15,7 @@
 """
 
 import logging as log
+import signal
 import sys
 from datetime import datetime
 from textwrap import dedent
@@ -35,9 +36,15 @@ class Main(Application):
     # The welcome message
     DESCRIPTION = (HERE / "welcome.txt").read_text()
 
+    # location of the .version file
+    VERSION_DIR = str(HERE)
+
+    # The resources folder
+    RESOURCE_DIR = str(HERE / "resources")
+
     def __init__(self, app_name: str):
-        version = AppVersion.load()
-        super().__init__(app_name, version, self.DESCRIPTION.format(version))
+        version = AppVersion.load(load_dir=self.VERSION_DIR)
+        super().__init__(app_name, version, self.DESCRIPTION.format(version), resource_dir=self.RESOURCE_DIR)
         self.vault = Vault()
 
     def _setup_arguments(self) -> None:
@@ -83,11 +90,22 @@ class Main(Application):
             VaultConfig.INSTANCE.vault_user(),
             VaultConfig.INSTANCE.vault_file(),
             datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
+
+        signal.signal(signal.SIGINT, self._abort)
+        signal.signal(signal.SIGTERM, self._abort)
+        signal.signal(signal.SIGABRT, self._abort)
+
         self._exec_application()
 
     def _cleanup(self) -> None:
+        """TODO"""
         self.vault.close()
 
+    def _abort(self, signum=0, frame=None) -> None:
+        """TODO"""
+        self._cleanup()
+        self.exit(signum, frame)
+
     def _exec_application(self, ) -> None:
         """Execute the specified vault operation"""
         op = self.getarg('operation')
